
#property copyright ""
#property link      ""

//---- input parameters
#define MAGICMA  20090302

extern double    Lots=               0.1;
extern double    MaximumRisk=        0.02;
extern double    DecreaseFactor=     1.5;
//---- input parameters
extern int       Fisher_Period=      10;


//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=Lots;
   int    orders=HistoryTotal();     // history orders total
   int    losses=0;                  // number of losses orders without a break
//---- select lot size
   lot=NormalizeDouble(AccountFreeMargin()*MaximumRisk/1000.0,1);
//---- calcuulate number of losses orders without a break
   if(DecreaseFactor>0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==false) { Print("Error in history!"); break; }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL) continue;
         //----
         if(OrderProfit()>0) break;
         if(OrderProfit()<0) losses++;
        }
      if(losses>1) lot=NormalizeDouble(lot-lot*losses/DecreaseFactor,1);
     }
//---- return lot size
   if(lot<0.1) lot=0.1;
   return(lot);
  }
//+------------------------------------------------------------------+
//| The EA initialization function                                   |
//+------------------------------------------------------------------+
int init()
  { 
    if(!IsTradeAllowed())
      {
        Print("Trade not allowed!");
        return(0);     
      }
      
  }  
  
 //+------------------------------------------------------------------+
//| The EA deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
  {
 
//Closing all orders
   for(int k = OrdersTotal() - 1; k >= 0 ; k--)
       if(OrderSymbol() == Symbol()) 
         {
           if(OrderType() == OP_BUY)
              OrderClose(OrderTicket(), OrderLots(), 
                         NormalizeDouble(Bid,Digits), 10);               
           if(OrderType() == OP_SELL)
               OrderClose(OrderTicket(), OrderLots(),
                          NormalizeDouble(Ask, Digits),10);                 
         }
         
  }  
//+------------------------------------------------------------------+
//|                                  |
//+------------------------------------------------------------------+
void OpenNew(int type)
  {
   int    res;

      //---- go trading only for first tiks of new bar
     if(Volume[0]>1) return;
     if(type==2)//sell order
       {
        res=OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,3,0,0,"",MAGICMA,0,Red);
           if(res>0)
              {
               if(OrderSelect(res,SELECT_BY_TICKET,MODE_TRADES)) Print("SELL order opened : ",OrderOpenPrice());
              }
            else Print("Error opening SELL order : ",GetLastError()); 
            return(0);
      }                    
    else if (type==1) //buy order
       {
         res=OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,3,0,0,"",MAGICMA,0,Green);
           if(res>0)
              {
               if(OrderSelect(res,SELECT_BY_TICKET,MODE_TRADES)) Print("BUY order opened : ",OrderOpenPrice());
              }
            else Print("Error opening BUY order : ",GetLastError()); 
            return(0);
      }  
 
    else if (type !=1 || type !=2 ) 
       Print("Error: Wrong New Order openning signal (1 or 2 only)!");

 }
   
//+------------------------------------------------------------------+
//|                                  |
//+------------------------------------------------------------------+
void CloseOrder(int type)
{
 
   if(Volume[0]>1) return;
      
       for(int i=0;i<OrdersTotal();i++)
       {
         if(OrderSelect(0,SELECT_BY_POS,MODE_TRADES)==false)  return;//   break;
         if(OrderMagicNumber()!=MAGICMA || OrderSymbol()!=Symbol()) continue;
           if(type ==1 && OrderType()==OP_BUY)
              OrderClose(OrderTicket(),OrderLots(),Bid,3,White);
            if(type ==2 && OrderType()==OP_SELL)
              OrderClose(OrderTicket(),OrderLots(),Ask,3,White);
        }       
}  

//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
{
       double fish0,fish1;
       
//---- check for history and trading
       Sleep(1000);      
       RefreshRates();
       if(Bars<100) return;
         datetime barTime; // global variable

      if( barTime < Time[0] )
       { 
         barTime = Time[0];
         fish0  = iCustom(NULL,0,"Fisher_Yur4ik",Fisher_Period,1000,0,0); 
         fish1  = iCustom(NULL,0,"Fisher_Yur4ik",Fisher_Period,1000,0,1);        
           if(fish0>-0.2 && fish1<=-0.2)
             {
               OpenNew(1);//buy order
               CloseOrder(2);//close sell order
             }
           else if(fish0<0.2 && fish1>=0.2)
             {
               OpenNew(2);//sell order
               CloseOrder(1);//close buy order
             }
        }       
}

